
%if 0%{?with_debug}
# https://bugzilla.redhat.com/show_bug.cgi?id=995136#c12
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif
%global grafana_home    /usr/share/grafana

%global app_name grafana
%global app_version 7.5.17
%global oracle_release_version 4
%global golang_version 1.17
%global nodejs_version 14.15
%global _buildhost build-ol%{?oraclelinux}-%{?_arch}.oracle.com

%ifarch %{arm} arm64 aarch64
%global custom_arch arm64
%else
%global custom_arch amd64
%endif

Name:               %{app_name}
Version:            %{app_version}
Release:            %{oracle_release_version}%{?dist}
Summary:            Grafana is an open source, feature rich metrics dashboard and graph editor
License:            ASL 2.0
URL:                https://github.com/grafana/grafana
Source:             %{name}-%{version}.tar.bz2
Vendor:             Oracle America
Patch0:             msigenerator-build.patch
Patch1:             yarn.lock.patch

BuildRequires:      golang >= %{golang_version}
BuildRequires:	    nodejs >= %{nodejs_version}
BuildRequires:      systemd
BuildRequires:      yarnpkg
%if %{?oraclelinux} == 8
BuildRequires:      npm
%endif

Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
Requires:           freetype-devel
Requires:           urw-fonts
Requires:           fontconfig
Obsoletes:          grafana-cloudwatch < 7.3.6-1
Obsoletes:          grafana-elasticsearch < 7.3.6-1
Obsoletes:          grafana-azure-monitor < 7.3.6-1
Obsoletes:          grafana-graphite < 7.3.6-1
Obsoletes:          grafana-influxdb < 7.3.6-1
Obsoletes:          grafana-loki < 7.3.6-1
Obsoletes:          grafana-mssql < 7.3.6-1
Obsoletes:          grafana-mysql < 7.3.6-1
Obsoletes:          grafana-opentsdb < 7.3.6-1
Obsoletes:          grafana-postgres < 7.3.6-1
Obsoletes:          grafana-prometheus < 7.3.6-1
Obsoletes:          grafana-stackdriver < 7.3.6-1
Provides:           grafana-cloudwatch = 7.3.6-1
Provides:           grafana-elasticsearch = 7.3.6-1
Provides:           grafana-azure-monitor = 7.3.6-1
Provides:           grafana-graphite = 7.3.6-1
Provides:           grafana-influxdb = 7.3.6-1
Provides:           grafana-loki = 7.3.6-1
Provides:           grafana-mssql = 7.3.6-1
Provides:           grafana-mysql = 7.3.6-1
Provides:           grafana-opentsdb = 7.3.6-1
Provides:           grafana-postgres = 7.3.6-1
Provides:           grafana-prometheus = 7.3.6-1
Provides:           grafana-stackdriver = 7.3.6-1

%description
Grafana is an open source, feature rich metrics dashboard and graph editor for
Graphite, InfluxDB & OpenTSDB.

%package -n grafana-docker-bin
Summary:            Grafana is an open source, feature rich metrics dashboard and graph editor
Requires:           fontconfig
Requires:           ca-certificates
Requires:           curl

%description -n grafana-docker-bin
Grafana is an open source, feature rich metrics dashboard and graph editor for
Graphite, InfluxDB & OpenTSDB.

%prep
%setup -q -n %{name}-%{version}
%patch0
%patch1
cd %{_builddir}
mkdir -p src/github.com/grafana/
rm -rf src/github.com/grafana/%{name}
mv %{name}-%{version} src/github.com/grafana/grafana
ln -sf src/github.com/grafana/grafana %{name}-%{version}

%build -q -n src/github.com/grafana/grafana
export GOPATH=%{_builddir}

%if %{?oraclelinux} == 9
export PUPPETEER_SKIP_DOWNLOAD='true'
export NODE_OPTIONS=--openssl-legacy-provider
%endif

yarn cache clean
yarn config set registry $(yarn config get registry)
yarn config set "strict-ssl" false
npm config set scripts-prepend-node-path true
yarn config set networkConcurrency 1
pushd %{_builddir}
mkdir temp
cd temp
yarn add mri@1.1.4 --registry $(yarn config get registry)
yarn add multimatch@4.0.0 --registry $(yarn config get registry)
yarn add resolve@1.12.0 --registry $(yarn config get registry)
# yarn add -W caniuse-lite --registry $(yarn config get registry)
popd
npx browserslist@latest --update-db  --force
yarn install --network-timeout 500000
npm run build
go run build.go -goos linux -pkg-arch %{custom_arch} ${OPT} build
mkdir -p _output/bin/
cp packaging/docker/run.sh _output/bin/
mkdir -p _output/bin/grafana/bin
cp -ap bin/linux-%{custom_arch}/* _output/bin/grafana/bin
cp -ap conf/ _output/bin/grafana/
cp -ap public/ _output/bin/grafana
cp -ap scripts/ _output/bin/grafana
cp -ap tools/ _output/bin/grafana
cp -p LICENSE _output/bin/grafana
cp -p NOTICE.md _output/bin/grafana
cp -p README.md _output/bin/grafana

%install
cd %{_builddir}/src/github.com/grafana/grafana
install -d -p %{buildroot}%{_datadir}/%{name}
cp -rp _output/bin/grafana %{buildroot}/usr/share/
install -p -m 644 -t %{buildroot}%{grafana_home} _output/bin/run.sh
cp -pav *.md %{buildroot}%{_datadir}/%{name}
cp -rpav docs %{buildroot}%{_datadir}/%{name}
install -d -p %{buildroot}%{_sbindir}
cp bin/*/%{name}-server %{buildroot}%{_sbindir}/
cp bin/*/%{name}-cli %{buildroot}%{_sbindir}/
install -d -p %{buildroot}%{_sysconfdir}/%{name}
cp conf/defaults.ini %{buildroot}%{_sysconfdir}/%{name}/grafana.ini
cp conf/ldap.toml %{buildroot}%{_sysconfdir}/%{name}/ldap.toml
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 packaging/rpm/systemd/grafana-server.service %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0644 packaging/rpm/sysconfig/grafana-server %{buildroot}%{_sysconfdir}/sysconfig
install -d -p %{buildroot}%{_sharedstatedir}/%{name}
install -d -p %{buildroot}/var/log/%{name}

%files -n grafana-docker-bin
%license LICENSE THIRD_PARTY_LICENSES.txt NOTICE.md olm/SECURITY.md
%attr(-, root, root) %{_datadir}/%{name}
%exclude %{_datadir}/%{name}/*.md
%exclude %{_datadir}/%{name}/docs
%attr(-, root, root) %doc %{_datadir}/%{name}/CHANGELOG.md
%attr(-, root, root) %doc %{_datadir}/%{name}/NOTICE.md
%attr(-, root, root) %doc %{_datadir}/%{name}/README.md
%attr(-, root, root) %doc %{_datadir}/%{name}/ROADMAP.md
%attr(-, root, root) %doc %{_datadir}/%{name}/docs

%files -n grafana
%license LICENSE THIRD_PARTY_LICENSES.txt NOTICE.md olm/SECURITY.md
%attr(0755, root, root) %{_sbindir}/%{name}-server
%attr(0755, root, root) %{_sbindir}/%{name}-cli
%attr(0755, root, grafana) %dir %{_sysconfdir}/%{name}
%attr(0640, root, grafana) %{_sysconfdir}/%{name}/grafana.ini
%attr(0640, root, grafana) %{_sysconfdir}/%{name}/ldap.toml
%attr(0755, grafana, grafana) %dir %{_sharedstatedir}/%{name}
%attr(0755, grafana, grafana) %dir /var/log/%{name}
%attr(-, root, root) %{_unitdir}/grafana-server.service
%attr(-, root, root) %{_sysconfdir}/sysconfig/grafana-server
%attr(-, grafana, grafana) %{_datadir}/%{name}
%exclude %{_datadir}/%{name}/*.md
%exclude %{_datadir}/%{name}/docs
%attr(-, root, root) %doc %{_datadir}/%{name}/CHANGELOG.md
%attr(-, root, root) %doc %{_datadir}/%{name}/NOTICE.md
%attr(-, root, root) %doc %{_datadir}/%{name}/README.md
%attr(-, root, root) %doc %{_datadir}/%{name}/ROADMAP.md
%attr(-, root, root) %doc %{_datadir}/%{name}/docs

%clean
rm -rf src

%pre -n grafana
getent group grafana >/dev/null || groupadd -r -g 472 grafana
getent passwd grafana >/dev/null || \
    useradd -r -u 472 -g grafana -d /etc/grafana -s /sbin/nologin \
    -c "Grafana Dashboard" grafana
exit 0

%post -n grafana
%systemd_post grafana.service

%preun -n grafana
%systemd_preun grafana.service

%postun -n grafana
%systemd_postun grafana.service

%changelog
* Fri Oct 6 2023 Guoyong Zhnag <guoyong.zhang@oracle.com> - 7.5.17-4
- Add Obsolete and Provides directives

* Fri Mar 24 2023 Padmanabha Bhat <padmanabha.bhat@oracle.com> - 7.5.17-3
- Update golang.org/x/net and golang.org/x/text

* Fri Jan 27 2023 fred.tibbitts <fred.tibbitts@oracle.com> - 7.5.17-2
- Upgrade crewjam/saml module

* Wed Dec 14 2022 michthom <michael.a.thompson@oracle.com> - 7.5.17-1
- Added Oracle Specific Build Files for grafana
